/*
 * DataAccess.java
 */

package edu.ba.de.java.kpi;

import java.io.*;
import java.sql.*;
import java.util.*;

/**
 * @author Kevin Niehage
 */
public class DataAccess {
    private final static String fID        = "ID";
    private final static char   fSeperator = ' ';
    
    /**
     * Diese Methode nimmt einen String und spaltet ihn anhand eines
     * gegebenen Trennzeichen auf. Die einzelnen Teile werden dann
     * in einem String-Array gespeichert.
     * Diese Methode wird nicht von auen genutzt, sondern ist lediglich
     * als Helfer-Methode fr andere Methoden in der Klasse DataAccess
     * verfgbar.
     */
    private static ArrayList<String> splitLine(final String aLine, final char aSeperator) {
        ArrayList<String> lResult = new ArrayList<String>();
        
        if (aLine != null) {
            boolean lRead = false;
            String  lItem = "";
            
            for (int lIndex = 0; lIndex < aLine.length(); lIndex++) {
                if (lRead) {
                    lRead = (aLine.charAt(lIndex) != aSeperator);
                    if (lRead) {
                        lItem += aLine.charAt(lIndex);
                    }
                    else {
                        lResult.add(lItem);
                        lItem = "";
                    }
                }
                else {
                    lRead = (aLine.charAt(lIndex) != aSeperator);
                    if (lRead) {
                        lItem += aLine.charAt(lIndex);
                    }
                }
            }
            
            if (!lItem.equalsIgnoreCase("")) {
                lResult.add(lItem);
            }
        }
        
        return lResult;
    }
    
    /**
     * Diese Methode nimmt die Daten aus einer DataList-Liste und schreibt
     * sie in die angegebene Tabelle.
     * Dabei wird nicht auf bereits vorhandene Eintrge berprft - es sind
     * also Mehrfacheintrge mglich.
     */
    public static int addDB(final String aHost, final String aDB, final String aPort, final String aTable, final String aUsername, final String aPassword, final ArrayList<DataList> aData) throws Exception {
        int lResult = 0;
    
        if (aData != null) {
            java.sql.Driver     lDriver     = new org.gjt.mm.mysql.Driver();
            java.sql.Connection lConnection = DriverManager.getConnection("jdbc:mysql://" + aHost + ":" + aPort + "/" + aDB, aUsername, aPassword);
            java.sql.Statement  lStatement  = lConnection.createStatement();

            DataList lItem = null;
            for (int lIndex = 0; lIndex < aData.size(); lIndex++) {
                lItem = aData.get(lIndex);

                lItem.setValue(DataList.CPUTIME, lItem.getValue(DataList.CPUTIME).replace(',', '.'));
                lItem.setValue(DataList.KOSTEN,  lItem.getValue(DataList.KOSTEN).replace(',', '.'));

                if (lStatement.execute("INSERT INTO " + aTable + " (" + DataList.RZNR_DB + ", " + DataList.CPUTIME_DB + ", " + DataList.KOSTEN_DB + ") VALUES (\"" + lItem.getValue(DataList.RZNR) + "\", \"" + lItem.getValue(DataList.CPUTIME) + "\", \"" + lItem.getValue(DataList.KOSTEN) + "\");")) {
                    lResult++;
                }
            }
            
            lConnection.close();
        }
        
        return lResult;
    }
    
    /**
     * Diese Methode erzeugt die angegebene Tabelle.
     * Dabei wird berprft, ob die angegebene Datenbank bereits existiert.
     * Wenn dies nicht der Fall ist, wird auch diese erzeugt.
     */
    public static boolean createDB(final String aHost, final String aDB, final String aPort, final String aTable, final String aUsername, final String aPassword) throws Exception {
        boolean lResult = false;
        
        Driver     lDriver     = new org.gjt.mm.mysql.Driver();
        Connection lConnection = DriverManager.getConnection("jdbc:mysql://" + aHost + ":" + aPort + "/", aUsername, aPassword);
        Statement  lStatement  = lConnection.createStatement();

        lStatement.execute("CREATE DATABASE IF NOT EXISTS " + aDB + " DEFAULT CHARACTER SET utf8 COLLATE utf8_unicode_ci;");
        lConnection.close();

        lConnection = DriverManager.getConnection("jdbc:mysql://" + aHost + ":" + aPort + "/" + aDB, aUsername, aPassword);
        lStatement  = lConnection.createStatement();
        
        lStatement.execute("DROP TABLE IF EXISTS " + aTable + ";");
        lResult = lStatement.execute("CREATE TABLE IF NOT EXISTS " + aTable + "(" + fID + " int(10) unsigned NOT NULL auto_increment, " + DataList.CPUTIME_DB + " double default '0', " + DataList.KOSTEN_DB + " double default '0', " + DataList.RZNR_DB + " varchar(5) collate utf8_unicode_ci default NULL, PRIMARY KEY  (" + fID + ")) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1;");
        
        lConnection.close();
        
        return lResult;
    }
    
    /**
     * Diese Methode liest die Informationen aus der angegebenen Datenbank
     * und speichert diese in einer DataList-Liste.
     */
    public static int loadDB(final String aHost, final String aDB, final String aPort, final String aTable, final String aUsername, final String aPassword, final ArrayList<DataList> aResult) throws Exception {
        int lResult = 0;
    
        if (aResult != null) {
            aResult.clear();
            
            Driver     lDriver     = new org.gjt.mm.mysql.Driver();
            Connection lConnection = DriverManager.getConnection("jdbc:mysql://" + aHost + ":" + aPort + "/" + aDB, aUsername, aPassword);
            Statement  lStatement  = lConnection.createStatement();
            ResultSet  lResultSet  = lStatement.executeQuery("SELECT * FROM " + aTable + ";");

            DataList lItem = null;
            while (lResultSet.next()) {
                lItem = new DataList();
                aResult.add(lItem);

                lItem.setValue(DataList.CPUTIME, lResultSet.getString(DataList.CPUTIME_DB));
                lItem.setValue(DataList.KOSTEN,  lResultSet.getString(DataList.KOSTEN_DB));
                lItem.setValue(DataList.RZNR,    lResultSet.getString(DataList.RZNR_DB));
                
                lResult++;
            }

            lConnection.close();
        }
        
        return lResult;
    }
    
    /**
     * Diese Methode liest die Eintrge aus der gegebenen Datei aus
     * und speichert diese in einer DataList-Liste ab.
     */
    public static int loadFile(final String aFile, final ArrayList<DataList> aResult) throws Exception {
        int lResult = 0;
        
        if (aResult != null) {
            aResult.clear();
            
            int               lIndex    = 0;
            DataList          lItem     = null;
            ArrayList<String> lList     = null;
            
            if (new File(aFile).isFile()) {
                BufferedReader lFile     = new BufferedReader(new FileReader(aFile));
                String         lNextLine = lFile.readLine();
                if (lNextLine != null) {
                    ArrayList<String> lCaptions = splitLine(lNextLine, fSeperator);
                    if (lCaptions.size() > 0) {
                        do {
                            lNextLine = lFile.readLine();

                            lList = splitLine(lNextLine, fSeperator);
                            if (lList.size() > 0) {
                                lItem = new DataList();
                                aResult.add(lItem);

                                for (lIndex = 0; lIndex < lList.size(); lIndex++) {
                                    if (lIndex < lCaptions.size()) {
                                        lItem.getItems().add(DataItem.create(lCaptions.get(lIndex), lList.get(lIndex)));
                                    }
                                }

                                lResult++;
                            }
                        } while (lNextLine != null);
                    }
                }
            }
        }
        
        return lResult;
    }
}
