/*
 * DataList.java
 */

package edu.ba.de.java.kpi;

import java.util.*;

/**
 * @author Kevin Niehage
 */
public class DataList extends Object {
    /**
     * Diese Konstanten definieren die Felder, die erforderlich sind,
     * um die minimalen Anforderungen zu erfllen.
     */
    public final static String CPUTIME = "CPUTIME";
    public final static String KOSTEN  = "KOSTEN";
    public final static String RZNR    = "RZ-NR";
    
    public final static String CPUTIME_DB = "CPUTIME";
    public final static String KOSTEN_DB  = "KOSTEN";
    public final static String RZNR_DB    = "RZNR";
    
    private ArrayList<DataItem> fItems = null;
    
    /**
     * Dieser Konstruktor erzeugt direkt die DataItem-Liste fItems.
     */
    public DataList() {
        super();
        
        fItems = new ArrayList<DataItem>();
    }
    
    /**
     * Diese Methode gibt die DataItem-Liste fItems zurck.
     */
    public ArrayList<DataItem> getItems() {
        return fItems;
    }

    /**
     * Diese Methode verkrzt lediglich den Aufruf von getItems().get().
     */
    public DataItem getItem(final int aIndex) {
        DataItem lResult = null;
        
        if ((aIndex >= 0) && (aIndex < getItems().size())) {
            lResult = getItems().get(aIndex);
        }
        
        return lResult;
    }
    
    /**
     * Diese Methode sucht nach einem DataItem, dessen Wert fName dem
     * bergebenen Namen entspricht.
     * Wird ein entsprechendes DataItem gefunden, wird dessen fValue Wert
     * zurckgegeben.
     * Wird solch ein DataItem nicht gefunden, wird null zurckgegeben.
     */
    public String getValue(final String aName) {
        String lResult = null;

        int lIndex = findItem(aName);
        if (lIndex >= 0) {
            lResult = getItem(lIndex).getValue();
        }
        
        return lResult;
    }
    
    /**
     * Diese Methode sucht nach einem DataItem, dessen Wert fName dem
     * bergebenen Namen entspricht.
     * Wird solch ein DataItem nicht gefunden, wird ein neues erzeugt.
     * Anschlieend wird der Wert fValue auf den bergegebenen Wert gesetzt.
     */
    public void setValue(final String aName, final String aValue) {
        int lIndex = findItem(aName);
        if (lIndex >= 0) {
            getItem(lIndex).setValue(aValue);
        }
        else {
            getItems().add(DataItem.create(aName, aValue));
        }
    }
    
    /**
     * Diese Methode sucht nach einem DataItem, dessen Wert fName dem
     * bergebenen Namen entspricht.
     * Wird ein entsprechendes DataItem gefunden, wird dessen Index
     * zurckgegeben.
     * Wird solch ein DataItem nicht gefunden, wird der Wert -1 zurckgegeben.
     */
    public int findItem(final String aName) {
        int lResult = - 1;
        
        for (int lIndex = 0; lIndex < getItems().size(); lIndex++) {
            if (getItem(lIndex).getName().equalsIgnoreCase(aName)) {
                lResult = lIndex;
                
                break;
            }
        }
        
        return lResult;
    }
    
    /**
     * Diese Methode sucht nach einem DataItem, dessen Wert fName dem
     * bergebenen Namen entspricht.
     * Wird ein entsprechendes DataItem gefunden, wird true zurckgegeben.
     * Wird solch ein DataItem nicht gefunden, wird der Wert false zurckgegeben.
     */
    public boolean isValueSet(final String aName) {
        return (findItem(aName) >= 0);
    }
}
