/*
 * KPIImport.java
 */

package edu.ba.de.java.kpi;

import java.awt.event.*;
import java.util.*;
import javax.swing.*;
import javax.swing.table.*;

/**
 * @author  Kevin Niehage
 */
public class KPIImport extends JFrame implements ActionListener {
    private KPIMain fOwner = null;

    private ArrayList<DataList> fData       = null;
    private DefaultTableModel   fTableModel = null;
    
    /**
     * Diese Methode wird benutzt, um das Import-Formular anzuzeigen.
     * Mit Hilfe der bergebenen Daten wird der Import-Vorgang gesteuert.
     */
    public void showDialog(final String aFile, final ArrayList<DataList> aData, final KPIMain aOwner) {
        fData  = aData;
        fOwner = aOwner;
        
        setTitle(getTitle() + ": " + aFile);
        showData(aData);
        setVisible(true);
    }
    
    /**
     * Dieser Konstruktor erzeugt eine neue Instanz.
     * Dabei wird das standardmig erzeugte TableModel durch ein eigenes
     * ersetzt, um alle Zellen auf ReadOnly zu setzen.
     */
    public KPIImport() {
        initComponents();
        
        fTableModel = new DefaultTableModel() {
            public boolean isCellEditable(int row, int col) {
                return false;
            }
        };
        KPITable.setModel(fTableModel);
    }
    
    /** 
     * Diese Methode wird vom Konstruktor aufgerufen, um das Formular
     * zu erzeugen.
     *
     * WARNUNG: Diesen Quelltext nicht modifieren, da er von der
     *          Entwicklungswieder wieder neu erzeugt und dabei berschrieben
     *          wird.
     */
    // <editor-fold defaultstate="collapsed" desc=" Erzeugter Quelltext ">//GEN-BEGIN:initComponents
    private void initComponents() {
        KPIScrollPane = new javax.swing.JScrollPane();
        KPITable = new javax.swing.JTable();
        ButtonPanel = new javax.swing.JPanel();
        ApplyButton = new javax.swing.JButton();
        CancelButton = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setTitle("Data-Import");
        setAlwaysOnTop(true);
        setName("KPIImport");
        KPITable.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null, null, null, null},
                {null, null, null, null},
                {null, null, null, null},
                {null, null, null, null}
            },
            new String [] {
                "Titel 1", "Titel 2", "Titel 3", "Titel 4"
            }
        ));
        KPIScrollPane.setViewportView(KPITable);

        ButtonPanel.setName("ButtonPanel");
        ApplyButton.setText("Apply");
        ApplyButton.setName("ApplyButton");
        ApplyButton.addActionListener(this);

        CancelButton.setText("Cancel");
        CancelButton.setName("CancelButton");
        CancelButton.addActionListener(this);

        org.jdesktop.layout.GroupLayout ButtonPanelLayout = new org.jdesktop.layout.GroupLayout(ButtonPanel);
        ButtonPanel.setLayout(ButtonPanelLayout);
        ButtonPanelLayout.setHorizontalGroup(
            ButtonPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, ButtonPanelLayout.createSequentialGroup()
                .addContainerGap(302, Short.MAX_VALUE)
                .add(ApplyButton)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(CancelButton)
                .addContainerGap())
        );
        ButtonPanelLayout.setVerticalGroup(
            ButtonPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(ButtonPanelLayout.createSequentialGroup()
                .add(ButtonPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(CancelButton)
                    .add(ApplyButton))
                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, KPIScrollPane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 446, Short.MAX_VALUE)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, ButtonPanel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, layout.createSequentialGroup()
                .add(KPIScrollPane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 227, Short.MAX_VALUE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(ButtonPanel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
        );
        pack();
    }

    // Quelltext zum Weiterleiten von Ereignissen von Komponenten zu Behandlungsmethoden.

    public void actionPerformed(java.awt.event.ActionEvent evt) {
        if (evt.getSource() == ApplyButton) {
            KPIImport.this.ApplyButtonClicked(evt);
        }
        else if (evt.getSource() == CancelButton) {
            KPIImport.this.CancelButtonClicked(evt);
        }
    }// </editor-fold>//GEN-END:initComponents

    /**
     * Diese Methode wird ausgefhrt, wenn auf den Button mit der Aufschritt
     * "Cancel" gedrckt wird.
     * In diesem Fall wird das derzeitige Fenster geschlossen.
     */
    private void CancelButtonClicked(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_CancelButtonClicked
        dispose();
    }//GEN-LAST:event_CancelButtonClicked

    /**
     * Diese Methode wird ausgefhrt, wenn auf den Button mit der Aufschritt
     * "Apply" gedrckt wird.
     * In diesem Fall wird das eigentliche Hauptfenster dazu veranlasst, die
     * importierten Daten in die Datenbank zu schreiben und diese danach
     * anzuzeigen.
     */
    private void ApplyButtonClicked(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_ApplyButtonClicked
        ArrayList<DataList> lResult = new ArrayList<DataList>();
        
        if (fOwner != null) {
            try {
                fOwner.importData(fData);

                dispose();
            }
            catch (Exception e) {Main.showError(e);}
        }
    }//GEN-LAST:event_ApplyButtonClicked
    
    /**
     * Diese Methode wird um die Daten aus einer DataList-Liste in der Tabelle
     * des derzeitigen Formulars anzeigen zu lassen.
     */
    public void showData(final ArrayList<DataList> aData) {
        int lIndex = 0;
        
        for (lIndex = 0; lIndex < fTableModel.getRowCount(); lIndex++) {
            fTableModel.removeRow(lIndex);
        }
        
        fTableModel.setColumnIdentifiers(new String[]{DataList.RZNR, DataList.CPUTIME, DataList.KOSTEN});
        
        if (aData != null) {
            DataList lItem = null;
            
            for (lIndex = 0; lIndex < aData.size(); lIndex++) {
                lItem = aData.get(lIndex);
                
                if (!lItem.isValueSet(DataList.CPUTIME)) {
                    lItem.setValue(DataList.CPUTIME, "");
                }
                if (!lItem.isValueSet(DataList.KOSTEN)) {
                    lItem.setValue(DataList.KOSTEN, "");
                }
                if (!lItem.isValueSet(DataList.RZNR)) {
                    lItem.setValue(DataList.RZNR, "");
                }
                
                fTableModel.addRow(new String[]{lItem.getValue(DataList.RZNR), lItem.getValue(DataList.CPUTIME), lItem.getValue(DataList.KOSTEN)});
            }
        }
    }
    
    // Variablendeklaration - nicht modifizieren//GEN-BEGIN:variables
    protected javax.swing.JButton ApplyButton;
    protected javax.swing.JPanel ButtonPanel;
    protected javax.swing.JButton CancelButton;
    protected javax.swing.JScrollPane KPIScrollPane;
    protected javax.swing.JTable KPITable;
    // Ende der Variablendeklaration//GEN-END:variables
}
