/*
 * KPIMain.java
 */

package edu.ba.de.java.kpi;

import java.util.*;
import javax.swing.*;
import javax.swing.table.*;

/**
 * @author  Kevin Niehage
 */
public class KPIMain extends javax.swing.JFrame implements java.awt.event.ActionListener {
    /**
     * Diese Konstanten stellen Standardwerte dar, die whrend der
     * Entwicklung genutzt wurden.
     */
    private static String fDatabase = "kpi";
    private static String fHost     = "localhost";
    private static String fPassword = "";
    private static String fPort     = "3306";
    private static String fUsername = "root";
    private static String fTable    = "daten";
    
    private DefaultTableModel fTableModel = null;
    
    /**
     * Dieser Konstruktor erzeugt eine neue Instanz.
     * Dabei wird das standardmig erzeugte TableModel durch ein eigenes
     * ersetzt, um alle Zellen auf ReadOnly zu setzen.
     */
    public KPIMain() {
        initComponents();
        
        fTableModel = new DefaultTableModel() {
            public boolean isCellEditable(int row, int col) {
                return false;
            }
        };
        KPITable.setModel(fTableModel);
        
        setTitle(getTitle() + ": " + fHost + ":" + fPort + "/" + fDatabase + "/" + fTable);
    }
    
    /** 
     * Diese Methode wird vom Konstruktor aufgerufen, um das Formular
     * zu erzeugen.
     *
     * WARNUNG: Diesen Quelltext nicht modifieren, da er von der
     *          Entwicklungswieder wieder neu erzeugt und dabei berschrieben
     *          wird.
     */
    // <editor-fold defaultstate="collapsed" desc=" Erzeugter Quelltext ">//GEN-BEGIN:initComponents
    private void initComponents() {
        KPIScrollPane = new javax.swing.JScrollPane();
        KPITable = new javax.swing.JTable();
        KPIMenuBar = new javax.swing.JMenuBar();
        KPIMenu = new javax.swing.JMenu();
        ImportMenuItem = new javax.swing.JMenuItem();
        CloseSeperator = new javax.swing.JSeparator();
        CloseMenuItem = new javax.swing.JMenuItem();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setTitle("KPI-Tool (TAI06ABC - Kevin Niehage)");
        setAlwaysOnTop(true);
        setName("KPIMain");
        KPITable.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null, null, null, null},
                {null, null, null, null},
                {null, null, null, null},
                {null, null, null, null}
            },
            new String [] {
                "Titel 1", "Titel 2", "Titel 3", "Titel 4"
            }
        ));
        KPIScrollPane.setViewportView(KPITable);

        KPIMenuBar.setName("KPIMenuBar");
        KPIMenu.setText("File");
        KPIMenu.setName("KPIMenu");
        ImportMenuItem.setText("Import");
        ImportMenuItem.setName("ImportMenuItem");
        ImportMenuItem.addActionListener(this);

        KPIMenu.add(ImportMenuItem);

        CloseSeperator.setName("CloseSeperator");
        KPIMenu.add(CloseSeperator);

        CloseMenuItem.setText("Close");
        CloseMenuItem.setName("CloseMenuItem");
        CloseMenuItem.addActionListener(this);

        KPIMenu.add(CloseMenuItem);

        KPIMenuBar.add(KPIMenu);

        setJMenuBar(KPIMenuBar);

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, KPIScrollPane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 447, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(KPIScrollPane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 246, Short.MAX_VALUE)
        );
        pack();
    }

    // Quelltext zum Weiterleiten von Ereignissen von Komponenten zu Behandlungsmethoden.

    public void actionPerformed(java.awt.event.ActionEvent evt) {
        if (evt.getSource() == CloseMenuItem) {
            KPIMain.this.CloseMenuItemClicked(evt);
        }
        else if (evt.getSource() == ImportMenuItem) {
            KPIMain.this.ImportMenuItemClicked(evt);
        }
    }// </editor-fold>//GEN-END:initComponents

    /**
     * Diese Methode wird ausgefhrt, wenn auf den Button mit der Aufschritt
     * "Apply" gedrckt wird.
     * In diesem Fall wird das eigentliche Hauptfenster erzeugt, dessen
     * Parameter gesetzt und das Fenster angezeigt.
     */
    private void ImportMenuItemClicked(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_ImportMenuItemClicked
        JFileChooser lDialog = new JFileChooser();
        
        if (lDialog.showOpenDialog(this) == JFileChooser.APPROVE_OPTION) {
            ArrayList<DataList> lData = new ArrayList<DataList>();
            try {
                DataAccess.loadFile(lDialog.getSelectedFile().toString(), lData);

                new KPIImport().showDialog(lDialog.getSelectedFile().toString(), lData, this);
            }
            catch (Exception e) {Main.showError(e);}
        }
    }//GEN-LAST:event_ImportMenuItemClicked

    /**
     * Diese Methode wird ausgefhrt, wenn auf den Menueintrag mit der Aufschritt
     * "Close" gedrckt wird.
     * In diesem Fall wird das eigentliche Hauptfenster geschlossen.
     */
    private void CloseMenuItemClicked(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_CloseMenuItemClicked
        dispose();
    }//GEN-LAST:event_CloseMenuItemClicked
    
    /**
     * Diese Methode wird benutzt, um die importierten Daten in die
     * Datenbank zu schreiben und danach die Daten in der Tabelle anzeigen
     * zu lassen.
     */
    public void importData(final ArrayList<DataList> aData) throws Exception {
        DataAccess.addDB(fHost, fDatabase, fPort, fTable, fUsername, fPassword, aData);
        showData();
        
        showData();
    }
    
    /**
     * Diese Methode wird benutzt, um die Daten aus der Datenbank in der
     * Tabelle anzeigen zu lassen.
     */
    public void showData() throws Exception {
        int lIndex = 0;
        
        for (lIndex = 0; lIndex < fTableModel.getRowCount(); lIndex++) {
            fTableModel.removeRow(lIndex);
        }
        fTableModel.setColumnIdentifiers(new String[]{DataList.RZNR, DataList.CPUTIME, DataList.KOSTEN});
        
        ArrayList<DataList> lData = new ArrayList<DataList>();
        DataList            lItem = null;

        DataAccess.loadDB(fHost, fDatabase, fPort, fTable, fUsername, fPassword, lData);
        for (lIndex = 0; lIndex < lData.size(); lIndex++) {
            lItem = lData.get(lIndex);

            if (!lItem.isValueSet(DataList.CPUTIME)) {
                lItem.setValue(DataList.CPUTIME, "");
            }
            if (!lItem.isValueSet(DataList.KOSTEN)) {
                lItem.setValue(DataList.KOSTEN, "");
            }
            if (!lItem.isValueSet(DataList.RZNR)) {
                lItem.setValue(DataList.RZNR, "");
            }

            fTableModel.addRow(new String[]{lItem.getValue(DataList.RZNR), lItem.getValue(DataList.CPUTIME), lItem.getValue(DataList.KOSTEN)});
        }
    }

    /**
     * Diese Methode gibt den Wert von fDatabase zurck.
     */
    public String getDatabase() {
        return fDatabase;
    }
    
    /**
     * Diese Methode gibt den Wert von fHost zurck.
     */
    public String getHost() {
        return fHost;
    }
    
    /**
     * Diese Methode gibt den Wert von fPassword zurck.
     */
    public String getPassword() {
        return fPassword;
    }
    
    /**
     * Diese Methode gibt den Wert von fPort zurck.
     */
    public String getPort() {
        return fPort;
    }
    
    /**
     * Diese Methode gibt den Wert von fUsername zurck.
     */
    public String getUsername() {
        return fUsername;
    }
    
    /**
     * Diese Methode gibt den Wert von fTable zurck.
     */
    public String getTable() {
        return fTable;
    }

    /**
     * Diese Methode setzt den Wert von fDatabase.
     */
    public void setDatabase(final String aValue) {
        fDatabase = aValue;
    }
    
    /**
     * Diese Methode setzt den Wert von fHost.
     */
    public void setHost(final String aValue) {
        fHost = aValue;
    }
    
    /**
     * Diese Methode setzt den Wert von fPassword.
     */
    public void setPassword(final String aValue) {
        fPassword = aValue;
    }
    
    /**
     * Diese Methode setzt den Wert von fPort.
     */
    public void setPort(final String aValue) {
        fPort = aValue;
    }
    
    /**
     * Diese Methode setzt den Wert von fUsername.
     */
    public void setUsername(final String aValue) {
        fUsername = aValue;
    }
    
    /**
     * Diese Methode setzt den Wert von fTable.
     */
    public void setTable(final String aValue) {
        fTable = aValue;
    }
    
    // Variablendeklaration - nicht modifizieren//GEN-BEGIN:variables
    protected javax.swing.JMenuItem CloseMenuItem;
    protected javax.swing.JSeparator CloseSeperator;
    protected javax.swing.JMenuItem ImportMenuItem;
    protected javax.swing.JMenu KPIMenu;
    protected javax.swing.JMenuBar KPIMenuBar;
    protected javax.swing.JScrollPane KPIScrollPane;
    protected javax.swing.JTable KPITable;
    // Ende der Variablendeklaration//GEN-END:variables
}
